<template>
  <div
    v-empty="nopermission"
    class="rc-cont"
    xs-empty-icon="nopermission"
    xs-empty-text="暂无权限">
    <flexbox
      v-if="crmType==='business'"
      class="rc-head"
      direction="row-reverse">
      <el-button
        class="rc-head-item"
        type="primary"
        @click.native="createClick">新建合同
      </el-button>
    </flexbox>
    <el-table
      :data="list"
      :height="tableHeight"
      :header-cell-style="headerRowStyle"
      :cell-style="cellStyle"
      style="width: 100%;border: 1px solid #E6E6E6;"
      @row-click="handleRowClick">
      <el-table-column
        v-for="(item, index) in fieldList"
        :key="index"
        :prop="item.prop"
        :formatter="fieldFormatter"
        :label="item.label"
        show-overflow-tooltip>
        <template
          slot="header"
          slot-scope="scope">
          <div class="table-head-name">{{ scope.column.label }}</div>
        </template>
       </el-table-column>
       <el-table-column prop="BeforeSealFile" label="盖章前合同">
            <template
              slot="header"
              slot-scope="scope">
              <div class="table-head-name">{{ scope.column.label }}</div>
            </template>
            <template slot-scope="scope">
              <span>{{scope.row.BeforeSealFile===''?'--':'点击下载'}}</span>
            </template>
          </el-table-column>
          <el-table-column prop="SealFile" label="盖章后合同">
            <template
              slot="header"
              slot-scope="scope">
              <div class="table-head-name">{{ scope.column.label }}</div>
            </template>
            <template slot-scope="scope">
              <span>{{scope.row.SealFile===''?'--':'点击下载'}}</span>
            </template>
          </el-table-column>
    </el-table>
    <div class="p-contianer" v-show='total>0'>
        <el-pagination
          :current-page="currentPage"
          :page-sizes="pageSizes"
          :page-size.sync="pageSize"
          :total="total"
          class="p-bar"
          layout="total, sizes, prev, pager, next, jumper"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"/>
      </div>

    <c-r-m-full-screen-detail
      :visible.sync="showFullDetail"
      :id="contractId"
      crm-type="contract"/>
    <el-dialog title="新建合同" :visible.sync="isCreate" :modal-append-to-body="false" width="30%">
      <c-r-m-create-file-view
        v-if="isCreate"
        :id="id"
        :action="createActionInfo"
        crm-type="contract"
        @save-success="createSaveSuccess"
        @hiden-view="isCreate=false"/>
    </el-dialog>
  </div>
</template>

<script type="text/javascript">
import loading from '../mixins/loading'
import CRMCreateFileView from './CRMCreateFileView'
import { GetCustomerAgreenmentList } from '@/api/customermanagement/customerManage'
import { GetSalesChanceAgreementList } from '@/api/customermanagement/business'
import { downloadFile } from '@/utils'
// import { moneyFormat } from '@/utils'

export default {
  name: 'RelativeContract', // 相关联系人  可能再很多地方展示 放到客户管理目录下
  components: {
    CRMFullScreenDetail: () => import('./CRMFullScreenDetail.vue'),
    CRMCreateFileView
  },
  mixins: [loading],
  props: {
    /** 模块ID */
    id: [String, Number],
    /** 没有值就是全部类型 有值就是当个类型 */
    crmType: {
      type: String,
      default: ''
    },
    /** 是公海 默认是客户 */
    isSeas: {
      type: Boolean,
      default: false
    },
    /** 联系人人下 新建商机 需要联系人里的客户信息  合同下需要客户和商机信息 */
    detail: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data () {
    return {
      nopermission: false,
      list: [],
      fieldList: [],
      tableHeight: '400px',
      showFullDetail: false,
      isCreate: false, // 控制新建
      contractId: '', // 查看全屏联系人详情的 ID
      // 创建的相关信息
      createActionInfo: { type: 'save', crmType: this.crmType, data: {} },
      total: 0,
      currentPage: 1,
      pageSize: 10,
      pageSizes: [10, 30, 60, 100]
    }
  },
  computed: {},
  watch: {
    id: function (val) {
      this.list = []
      this.getDetail()
    }
  },
  mounted () {
    this.getDetail()
  },
  activated: function () {},
  deactivated: function () {},
  methods: {
    handleSizeChange (newSize) {
      this.pageSize = newSize
      this.getDetail()
    },
    handleCurrentChange (newPage) {
      this.currentPage = newPage
      this.getDetail()
    },
    /** 格式化字段 */
    fieldFormatter (row, column) {
      if (column.property === 'Sex') {
        return { 1: '男', 2: '女' }[row.Sex]
      } else if (column.property === 'IsCustomerDefault') {
        return { true: '是', false: '否' }[row.IsCustomerDefault]
      } else if (column.property === 'CompanyType') {
        return {0: '暂无', 1: '国企', 2: '外企', 3: '民营', 4: '其他'}[row.CompanyType]
      } else if (column.property === 'SealStatus') {
        return this.getStatusName(row.SealStatus)
      } else if (column.property === 'SealType') {
        return this.getSealName(row.SealType)
      } else if (column.property === 'AuditStatus') {
        return this.getAuditStatus(row.AuditStatus)
      } else if (column.property === 'IsSeal') {
        return this.getSwitch(row.IsSeal)
      }
      // 如果需要格式化
      return row[column.property] || '--'
    },
    getFieldList () {
      this.fieldList.push(
        { prop: 'AgreeName', label: '合同名称' },
        { prop: 'Comment', label: '合同备注' },
        { prop: 'AuditStatus', label: '是否审核', width: '100' },
        { prop: 'AuditUserName', label: '审核人' },
        { prop: 'SealType', label: '合同类型' },
        { prop: 'IsSeal', label: '是否盖章', width: '100' },
        { prop: 'SealUserName', label: '盖章上传人' },
        { prop: 'CreateTime', label: '创建时间' },
        { prop: 'ExpressNumber', label: '快递单号' },
        { prop: 'ExpressComment', label: '快递备注信息' }
        // { prop: 'BeforeSealFile', label: '盖章前合同' },
        // { prop: 'SealFile', label: '盖章后合同' }
      )
    },
    getDetail () {
      this.loading = true
      const request = {
        customer: GetCustomerAgreenmentList,
        businessCustomer: GetCustomerAgreenmentList,
        business: GetSalesChanceAgreementList,
        businessChances: GetSalesChanceAgreementList
      }[this.crmType]
      const params = {}
      params['Id'] = this.id
      params['PageSize'] = this.pageSize
      params['PageIndex'] = this.currentPage
      request(params)
        .then(res => {
          if (this.fieldList.length === 0) {
            this.getFieldList()
          }
          this.nopermission = false
          this.loading = false
          this.list = res.data.Result.List
          this.total = res.data.Result.Count
        })
        .catch(data => {
          if (data.code === 102) {
            this.nopermission = true
          }
          this.loading = false
        })
    },

    /**
     * 对应的状态名
     */
    getStatusName (status) {
      if (status === 1) {
        return '已盖章'
      } else if (status === 2) {
        return '未盖章'
      }
      return '暂无'
    },
    getSealName (type) {
      if (type === 1) {
        return '合同章'
      } else if (type === 2) {
        return '公章'
      }
      return '暂无'
    },
    getAuditStatus (type) {
      if (type === 1) {
        return '审批中'
      } else if (type === 2) {
        return '通过'
      } else if (type === 3) {
        return '驳回'
      }
      return '暂无'
    },
    getSwitch (type) {
      if (type === false) {
        return '否'
      } else if (type === true) {
        return '是'
      }
      return '暂无'
    },
    // 当某一行被点击时会触发该事件
    handleRowClick (row, column, event) {
      if (column.property === 'BeforeSealFile' || column.property === 'SealFile') {
        if (column.property === 'BeforeSealFile' && row.BeforeSealFile !== '') {
          this.handleFile(column, row)
        }
        if (column.property === 'SealFile' && row.SealFile !== '') {
          this.handleFile(column, row)
        }
      }
      // else if (column.property === 'ChanceName') {
      //   this.rowID = row.Id
      //   this.businessId = row.Id
      //   this.rowType = 'business'
      //   this.showFullDetail = true
      // }
    },
    handleFile (column, data) {
      if (column.property === 'BeforeSealFile') {
        downloadFile({ path: data.BeforeSealFile, name: data.BeforeSealFile })
      } else if (column.property === 'SealFile') {
        downloadFile({ path: data.SealFile, name: data.SealFile })
      }
    },
    /** 通过回调控制表头style */
    headerRowStyle ({ row, column, rowIndex, columnIndex }) {
      return { textAlign: 'left' }
    },
    /** 通过回调控制style */
    cellStyle ({ row, column, rowIndex, columnIndex }) {
      if (column.property === 'BeforeSealFile' || column.property === 'SealFile') {
        return { color: '#4D88FF', cursor: 'pointer' }
      } else if (column.property === 'AuditStatus') {
        if (row[column.property] === 1) {
          return { color: '#FF8800' }
        } else if (row[column.property] === 2) {
          return { color: '#2DB300' }
        } else if (row[column.property] === 3) {
          return { color: '#FF4D4D' }
        }
      } else {
        return { textAlign: 'left' }
      }
    },
    /** 新建 */
    createClick () {
      /** 客户 和 商机 下新建合同 */
      if (this.crmType === 'business') {
        this.createActionInfo.data['customer'] = this.detail
        this.createActionInfo.data['business'] = this.detail
      } else if (this.crmType === 'customer') {
        this.createActionInfo.data['customer'] = this.detail
      }
      this.isCreate = true
    },
    createSaveSuccess () {
      this.getDetail()
      this.isCreate = false
    }
  }
}
</script>
<style lang="scss" scoped>
@import '../styles/relativecrm.scss';
</style>
